@@ -88,6 +88,7 @@ class mysqlUtil:
     def chk_file_exist_surl(self,surl,fdesc):
         if surl and fdesc:
             # 判断float相等： abs(duration-123.31)<0.01
+            surl=surl[0:100] #只取前100位
             sql = "select id from sftp_files where surl='{}' or fdesc='{}' limit 1".format(surl,fdesc)
             connection = self.engine.connect()
             df = pd.read_sql(text(sql), con=connection)
@@ -104,6 +105,7 @@ class mysqlUtil:
         try:
             df = pd.DataFrame(columns=['filename', 'url', 'stud', 'fdesc', 'fsize', 'duration', 'ftype','pid','surl'])
             # print(df)
+            surl=surl[0:100] #截取字符串前100个字符
             row1 = pd.DataFrame(
                 {'filename': filename, 'url': url, 'stud': stud, 'fdesc': fdesc, 'fsize': fsize, 'duration': duration,
                  'ftype': ftype,'pid':pid,'surl':surl}, index=[1])
